**Example 1: 获取资产数量概况**



Input: 

```
tccli cwp DescribeAssetInfo --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "xx",
        "MachineCount": 100,
        "AccountCount": 100,
        "PortCount": 100,
        "ProcessCount": 100,
        "SoftwareCount": 100,
        "DatabaseCount": 100,
        "WebAppCount": 100,
        "WebFrameCount": 100,
        "WebServiceCount": 100,
        "WebLocationCount": 100,
        "AccountNewCount": 100,
        "PortNewCount": 100,
        "ProcessNewCount": 100,
        "SoftwareNewCount": 100,
        "DatabaseNewCount": 100,
        "WebAppNewCount": 100,
        "WebFrameNewCount": 100,
        "WebServiceNewCount": 100,
        "WebLocationNewCount": 100,
        "MachineNewCount": 100
    }
}
```

